function [f, df, ddf] = styblinski_tang_n(x)
%STYBLINSKI_TANG_N calculates the N-dimensional stiblinsky tang function
%
%   Input arguments:
%   x...N-Dimensional vector;
%   
%   Oputput Arguments
%   f...value of the Styblinski-Tang function at x
%   df...value of the gradient of the Styblinski-Tang function at x
%   ddf...value of the hessian of the Styblinski-Tang function at x

% force x to be a column vector
x = x(:);

% calculate function value at x
f=1/2*sum(x.^4-16*x.^2+5*x);
  
% calculate gradient at x
df=1/2*(4*x.^3-32*x+5);
  

% calculate hessian at x
ddf=diag(1/2*(12*x.^2-32));
end
